// CellWnd.cpp : implementation file
//

#include "stdafx.h"
#include "CellWnd.h"
#include "HWEncTestDlg.h"

extern CHWEncTestDlg* g_pTestDlg;  

/////////////////////////////////////////////////////////////////////////////////
// CCellWnd
/////////////////////////////////////////////////////////////////////////////////
const CBrush CCellWnd::sm_brBackground( RGB(2,2,2) );
int CCellWnd::sm_nActiveIndex = 0;

IMPLEMENT_DYNAMIC(CCellWnd, CWnd)

CCellWnd::CCellWnd( BOOL bFullScreen )
{
    // Register cell window class.
    WNDCLASS wndClass = {0};
    wndClass.lpfnWndProc   = ::DefWindowProc;
    wndClass.hInstance     = AfxGetInstanceHandle();
    wndClass.hCursor       = AfxGetApp()->LoadStandardCursor(IDC_ARROW);
    wndClass.hbrBackground = (HBRUSH)sm_brBackground;
    wndClass.lpszClassName = CELL_WINDOW_CLASS;
    VERIFY( AfxRegisterClass( &wndClass ) );

    m_nIndex = 0;
    m_DisplayScale = DISPLAY_ORIGINAL;
    m_FullScreenState = bFullScreen ? LEAVE_FULL_SCREEN : NOT_SUPPORT_FULL_SCREEN;


}

CCellWnd::~CCellWnd()
{
}


BEGIN_MESSAGE_MAP(CCellWnd, CWnd)
    ON_WM_PAINT()
    ON_WM_LBUTTONDOWN()
    ON_WM_RBUTTONDOWN()
    ON_WM_SIZE()
    ON_WM_CREATE()
    ON_WM_CONTEXTMENU()
    ON_WM_DESTROY()
//    ON_MESSAGE(WM_FILE_END, &CCellWnd::OnFileEnd)
//    ON_MESSAGE(MSG_INDEX_OK, &CCellWnd::OnIndexEnd)
END_MESSAGE_MAP()



// CCellWnd message handlers

void CCellWnd::OnPaint()
{
    CPaintDC dc(this); // device context for painting
    // TODO: Add your message handler code here
    // Do not call CWnd::OnPaint() for painting messages

    if ( sm_nActiveIndex == m_nIndex
        && NOT_SUPPORT_FULL_SCREEN == m_FullScreenState )  // Full screen need not draw red rectangle
    {
        CRect rcClient;
        GetClientRect( rcClient );
        dc.Draw3dRect( rcClient, ACTIVE_LINE_COLOR, ACTIVE_LINE_COLOR );
    }
}

void CCellWnd::OnLButtonDown(UINT nFlags, CPoint point)
{
	// TODO: Add your message handler code here and/or call default
	Active();
	CWnd::OnLButtonDown(nFlags, point);
}

void CCellWnd::OnRButtonDown(UINT nFlags, CPoint point)
{
    // TODO: Add your message handler code here and/or call default
    Active();
    CWnd::OnRButtonDown(nFlags, point);
}

void CCellWnd::Active( void )
{
	if ( sm_nActiveIndex != m_nIndex )
	{
		// Set new active cell window.
		int nOldIndex = sm_nActiveIndex;
		sm_nActiveIndex = m_nIndex;
		CCellWnd* pCellWnd = g_pTestDlg->GetCellWnd( nOldIndex );
		
        pCellWnd->Invalidate();                         // Force to redraw window.
        Invalidate();								    // Force to redraw window.
	}
}

void CCellWnd::OnSize(UINT nType, int cx, int cy)
{
    CWnd::OnSize(nType, cx, cy);

    // TODO: Add your message handler code here
    if ( sm_nActiveIndex == m_nIndex )
    {
        // Update the current active window.
        Invalidate();
    }
    SetDisplayScale( m_DisplayScale );
}

int CCellWnd::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
    if (CWnd::OnCreate(lpCreateStruct) == -1)
        return -1;

    // TODO:  Add your specialized creation code here
    VERIFY(m_VideoWnd.CreateEx( 0, VIDEO_WINDOW_CLASS, NULL,
        WS_CHILD | WS_VISIBLE | WS_CLIPCHILDREN, CRect(0,0,0,0), this,
        AFX_IDW_CONTROLBAR_FIRST ));

    return 0;
}


void CCellWnd::SetDisplayScale( DISPLAY_SCALE DisplayScale )
{
    CRect rcClient;
    GetClientRect( rcClient );

    CRect rcMaxDisplay = rcClient;
    rcMaxDisplay.left   += ACTIVE_LINE_WIDTH;
    rcMaxDisplay.top    += ACTIVE_LINE_WIDTH;
    rcMaxDisplay.right  -= ACTIVE_LINE_WIDTH + ACTIVE_LINE_WIDTH;
    rcMaxDisplay.bottom -= ACTIVE_LINE_WIDTH + ACTIVE_LINE_WIDTH;

    int w = rcMaxDisplay.Width();
    int h = rcMaxDisplay.Height();
    CRect rcDisplay;
    rcDisplay.SetRectEmpty();

    switch ( DisplayScale )
    {
    case DISPLAY_ORIGINAL:
        if (1)
		{
            rcDisplay = CalcRectangleScale( rcMaxDisplay, 352,
                288 );
        }
		
        else
        {
            // Equal to DISPLAY_FULL.
            rcDisplay = rcMaxDisplay;
        }
        m_DisplayScale = DisplayScale;
        break;

    case DISPLAY_FULL:
        rcDisplay = rcMaxDisplay;
        m_DisplayScale = DisplayScale;
        break;

    case DISPLAY_16_9:
        rcDisplay = CalcRectangleScale( rcMaxDisplay, 16, 9 );
        m_DisplayScale = DisplayScale;
        break;

    case DISPLAY_5_4:
        rcDisplay = CalcRectangleScale( rcMaxDisplay, 5, 4 );
        m_DisplayScale = DisplayScale;
        break;

    case DISPLAY_4_3:
        rcDisplay = CalcRectangleScale( rcMaxDisplay, 4, 3 );
        m_DisplayScale = DisplayScale;
        break;

    default:
        ASSERT(FALSE);

        break;
    }

    // Adjust video window's position.
    m_VideoWnd.Invalidate();
    m_VideoWnd.MoveWindow( rcDisplay );
}


CRect CCellWnd::CalcRectangleScale( const CRect& rcSource, int nXScale, int nYScale )
{
    ASSERT(nXScale>0);
    ASSERT(nYScale>0);

    double w = rcSource.Width();
    double h = rcSource.Height();
    CPoint pt = rcSource.CenterPoint();
    CRect rcDestination = rcSource;

    if ( nYScale * w >= nXScale * h )
    {
        int nFitWidth = int(nXScale * h / nYScale);
        rcDestination.left  = pt.x - nFitWidth / 2;
        rcDestination.right = pt.x + nFitWidth / 2;
    }
    else
    {
        int nFitHeight = int(nYScale * w / nXScale);
        rcDestination.top    = pt.y - nFitHeight / 2;
        rcDestination.bottom = pt.y + nFitHeight / 2;
    }

    return rcDestination;
}

void CCellWnd::GetVideoColor( long& nBrightness, long& nContrast,
    long& nSaturation, long& nHue ) const
{
}


void CCellWnd::OnDestroy()
{
    CWnd::OnDestroy();

    // TODO: Add your message handler code here
}

BOOL CCellWnd::PreTranslateMessage(MSG* pMsg)
{
    // TODO: Add your specialized code here and/or call the base class
    if ( WM_KEYDOWN == pMsg->message )
    {
        switch ( pMsg->wParam )
        {
        case VK_ESCAPE:
            if ( ENTER_FULL_SCREEN == m_FullScreenState )
            {
                //LeaveFullScreen();
            }
            break;

        default:
            break;
        }
    }

    return CWnd::PreTranslateMessage(pMsg);
}
