#pragma once

#include "VideoWnd.h"
//#include "OpenStream.h"


class CPlayCtrl;

// CCellWnd
#define CELL_WINDOW_CLASS _T("CellWindowClass")


class CCellWnd : public CWnd
{
	DECLARE_DYNAMIC(CCellWnd)
public:
    CCellWnd( BOOL bFullScreen = FALSE );
    virtual ~CCellWnd();
	CVideoWnd m_VideoWnd;                           // Video window object.
private:
    enum
    {
        ACTIVE_LINE_WIDTH = 1,                      // Only support 1
        ACTIVE_LINE_COLOR = RGB(255,0,0),

        FULL_SCREEN_REGION_INDEX = 1,
	};

    const static CBrush sm_brBackground;            // Background brush.

//	CVideoWnd m_VideoWnd;                           // Video window object.

    enum FULL_SCREEN_STATE
    {
        NOT_SUPPORT_FULL_SCREEN,                    // Not support full screen

        // Support full screen.
        LEAVE_FULL_SCREEN,
        ENTER_FULL_SCREEN,
    } m_FullScreenState;                            // Flag to support full screen.

public:
    static int sm_nActiveIndex;                     // Active cell window index.
    int m_nIndex;                                   // Index of cell window array.
    
    enum DISPLAY_SCALE
    {
        DISPLAY_ORIGINAL,                           // Original scale, which is default
        DISPLAY_FULL,                               // Full window
        DISPLAY_16_9,                               // Scale 16:9
        DISPLAY_5_4,                                // Scale 5:4
        DISPLAY_4_3,                                // Scale 4:3
    } m_DisplayScale;                               // Video window display scale.

private:
    // Calculate the rectangle of the video window.
    CRect CalcRectangleScale( const CRect& rcSource, int nXScale, int nYScale );

    // Post WM_PLAY_STATE_CHANGED message to the Play Control window.
    void ChangePlayState() const;

    // Post WM_TITLE_CHANGE message to the main frame.
	void ChangeMainTitle() const;

    // Retrieve video color setting.
	void GetVideoColor( long& nBrightness, long& nContrast, long& nSaturation,
		long& nHue ) const;


public:
    // Active windows, draw a red rectangle.
    void Active(void);

    // Set video display scale.
    void SetDisplayScale( DISPLAY_SCALE DisplayScale );

    // Enter or leave full screen.

    BOOL IsFullScreen() const { return (ENTER_FULL_SCREEN == m_FullScreenState); }

protected:
	DECLARE_MESSAGE_MAP()
    afx_msg void OnPaint();
    afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
    afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
    afx_msg void OnSize(UINT nType, int cx, int cy);
    afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
//    afx_msg void OnContextMenu(CWnd* pWnd, CPoint point);
	afx_msg void OnDestroy();
    afx_msg LRESULT OnFileEnd(WPARAM wParam, LPARAM lParam);
    afx_msg LRESULT OnIndexEnd(WPARAM wParam, LPARAM lParam);
    virtual BOOL PreTranslateMessage(MSG* pMsg);
};