////////////////////////////////////////////////////////////////////////////////
// Copyright (C), 2009-2010, Beijing Hanbang Technology, Inc.
////////////////////////////////////////////////////////////////////////////////
//
// File Name:   HBPlaySDK.h
// Author:      
// Version:     3.00
// Date:        
// Description: Header file of HBPlaySDK.dll and HBPlaySDK.lib.
// History:
//
////////////////////////////////////////////////////////////////////////////////

#ifndef __HB_PLAYSDK_H__
#define __HB_PLAYSDK_H__


////////////////////////////////////////////////////////////////////////////////
// Macro definition.
////////////////////////////////////////////////////////////////////////////////

#define HBAPI extern"C"

// the message sent when the index has been created
#define MSG_INDEX_OK            (WM_USER+154)
// the maximum number of regions for display in a channel.
#define MAX_DISPLAY_WND         4 

// frame type
#define UNKOWN_FRAME_TYPE       0x0000      // unknown frame type
#define VIDEO_FRAME_I           0x2000      // video I-frame
#define VIDEO_FRAME_P           0x2001      // video P-frame
#define VIDEO_FRAME_B           0x2002      // video B-frame
#define AUDIO_FRAME_ALAW        0x1000      // audio A-law
#define AUDIO_FRAME_G722        0x1001      // audio G722
#define AUDIO_FRAME_G726        0x1002      // audio G726
#define AUDIO_FRAME_PCM8_16     0x1003      // audio compressed 8-bit linear PCM

// the decoding formats for the output
#define OUT_FMT_YUV_420         0x00000601  // YUV420
#define OUT_FMT_YUV_422         0x00000102  // YUV422
#define OUT_FMT_RGB_032         0x00000204  // RGB32
#define OUT_FMT_RGB_024         0x00000303  // RGB24
#define OUT_FMT_RGB_565         0x00000402  // RGB565
#define OUT_FMT_RGB_555         0x00000502  // RGB555
#define OUT_FMT_AUDIO           0x00000602  // audio


////////////////////////////////////////////////////////////////////////////////
// Structure definition.
////////////////////////////////////////////////////////////////////////////////

// The data type of input.
enum HB_PLAY_MODE
{
    HB_FILE_MODE,                       // Read data from a file.
    HB_STREAM_REALTIME_MODE,            // Receive real-time data.
    HB_STREAM_FILE_MODE                 // Input data from a file as stream.
};

// The type of hardware accelerated decoder.
enum HB_HD_TYPE
{
    HB_HD_NOT_SUPPORTED=1,
    HB_HD_AUTO,            // Determines the decoder according to graphics type.
    HB_HD_NVIDIA_CUDA,     // NVIDIA graphics solution.
    HB_HD_MS_DXVA          // Microsoft solution.
};

// detailed information of the frame
typedef struct _HB_FRAME
{
    DWORD           dwFrameNumber;      // frame number, incremental

    WORD            wFrameType;         // frame type
    BYTE            cbAlgorithm;        // algorithm
    BYTE            cbVersion;          // version

    WORD            wWidth;             // picture width in pixels
    WORD            wHeight;            // picture height in pixels

    DWORD           dwDTS;              // the time stamp of the frame, in milliseconds
    SYSTEMTIME      ETS;                // the system time when encoded

    DWORD           dwEncryptFlag;      // encrypt flag
    DWORD           dwEncryptKey;       // encrypt key
    DWORD           dwEncryptText;      // encrypt text

    WORD            wOsdFlag;           // OSD flag, valid only for video frame
    WORD            wOsdLines;          // Represents the OSD lines if the wOsdFlag 
                                        // parameter is not null, otherwise null. 
    LPVOID          pOsd;               // the long pointer to the OSD information
    DWORD           dwReserved;         // reserved for  alignment 

    ULARGE_INTEGER  ulOffset;           // the offset of bytes from the beginning of file
                                        // to the current position

    DWORD           dwHeaderSize;       // the size of the frame header 
    PVOID           pHeader;            // the pointer to the frame header

    DWORD           dwDataSize;         // the size of the frame data
    PVOID           pData;              // the pointer to the frame data

    DWORD           Reserved[8];        // reserved
}HB_FRAME, *PHB_FRAME;

// brief information of the frame
typedef struct	_HB_FRAME_INFO
{
    long            nWidth;             // picture width in pixels, 0 if audio
    long            nHeight;            // picture height in pixels, 0 if audio
    long            nStamp;             // the time stamp of the frame in milliseconds
    long            nType;              // the decoding format for the output
    long            nFrameRate;         // frame rate
}HB_FRAME_INFO, *PHB_FRAME_INFO;

// time information of the frame
typedef	struct _HB_VIDEO_TIME
{
    short           year;               // year
    short           month;              // month
    short           day;                // day
    short           hour;               // hour
    short           minute;	            // minute
    short           second;             // second
    short           milli;              // millisecond
    short           week;               // week
}HB_VIDEO_TIME, *PHB_VIDEO_TIME;

// position information of the frame
typedef struct _HB_FRAME_POS
{
    // the offset of bytes from the beginning of file to the current position
    ULARGE_INTEGER  nFilePos;
    long            nFrameNum;          // frame number
    long            nFrameTime;         // the time stamp of the frame in milliseconds
}HB_FRAME_POS, *PHB_FRAME_POS;

// single frame information
typedef struct _HB_FRAME_INFO_EX
{
    WORD            wFrameType;         // frame type
    WORD            wReserved;

    DWORD           dwFrameSize;        // the frame size, in bytes
    PVOID           pFrame;             // the pointer to the frame buffer

    // Only for video frame.
    DWORD           dwWidth;            // picture width in pixels
    DWORD           dwHeight;           // picture height in pixels
    DWORD           dwDTS;              // the time stamp of the frame in milliseconds

    // Only for audio frame.
    DWORD           dwSampleRate;       // audio sampling rate
    DWORD           dwSampleBit;        // audio sampling bits

    DWORD           dwReserved[4];      // reserved
}HB_FRAME_INFO_EX, *PHB_FRAME_INFO_EX;

////////////////////////////////////////////////////////////////////////////////
// Callback functions definition.
////////////////////////////////////////////////////////////////////////////////

// For HB_PLAY_SetParseCallBackEx.
typedef void (CALLBACK* LPSRCDATAPARSECBFUNEX)(long nChl, const HB_FRAME* pFrame, LPVOID pContext);

// For HB_PLAY_SetParseCallBack.
typedef void (CALLBACK* LPSRCDATAPARSECBFUN)(long nChl, char* SrcDataBuf,
            long nFrameType, long nReserved1, long nReserved2, HB_VIDEO_TIME ets);

// For HB_PLAY_SetDecCallBack and HB_PLAY_SetDecCallBackEx.
typedef void (CALLBACK* LPDECCBFUN)(long nChl, char* pBuf, long nSize,
            HB_FRAME_INFO* pFrameInfo, LPVOID pContext, long nReserved);

// For HB_PLAY_RegisterDrawDCFun
typedef void (CALLBACK* LPDRAWDCFUN)(long nChl, HDC hDC, long nReserved);

// For HB_PLAY_SetSnapShotCallBack
typedef void (CALLBACK* LPSNAPSHOTCBFUN)(long nChl, DWORD nSize, char* pBuf,
            long nWidth, long hHeight, long nType);

// For HB_PLAY_SetIndexInfoCallBack
typedef void (CALLBACK* LPINDEXCBFUN)(long nChl, long nReserved);

// For HB_PLAY_SetDisplayCallBack.
typedef void (CALLBACK* LPDISPLAYCBFUN)(long nChl, char* pBuf, long nSize, long nWidth, 
            long hHeight, long nStamp, long nType, long nReserved);

// For HB_PLAY_SetDecCallBackWithTime.
typedef void (CALLBACK* LPDECCBFUNWITHTIME)(long nChl, char* pBuf, long nSize,
            HB_FRAME_INFO* pFrameInfo, long nReserved1, long nReserved2, HB_VIDEO_TIME ets);

// For HB_PLAY_SetSourceBufferCB.
typedef void (CALLBACK* LPSOURCEBUFCALLBACK)(long nChl, DWORD dwBufSize,
            void* pUser, void* pResvered);


////////////////////////////////////////////////////////////////////////////////
// Functions definition.
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OpenFile.
// Description:
//      Opens a Hangban video file.
// Parameters:
//      [in] nChl - Channel number.
//      [in] sFile - File name.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Must call this function before operating a channel. When the channel is
//      no longer needed, close it by HB_PLAY_CloseFile.
//      There are two versions of the function, ANSI and Unicode:
//      HB_PLAY_OpenFileA, ANSI version.
//      HB_PLAY_OpenFileW, Unicode version.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_OpenFile(long nChl, LPCSTR sFile);
HBAPI BOOL __stdcall HB_PLAY_OpenFileA(long nChl, LPCSTR sFile);
HBAPI BOOL __stdcall HB_PLAY_OpenFileW(long nChl, LPCWSTR sFile);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OpenFileEx.
// Description:
//      Opens a Hangban video file.
// Parameters:
//      [in] sFile - File name.
// Return:
//      If the channel is opened successfully, this function returns a valid channel
//      number, which can also be considered as channel handle; otherwise returns 0.
// Remarks:
//      Must call this function before operating a channel. When the channel is
//      no longer needed, close it by HB_PLAY_CloseFile.
//      There are two versions of the function, ANSI and Unicode:
//      HB_PLAY_OpenFileExA, ANSI version.
//      HB_PLAY_OpenFileExW, Unicode version.
////////////////////////////////////////////////////////////////////////////////
HBAPI long __stdcall HB_PLAY_OpenFileEx(LPCSTR sFile);
HBAPI long __stdcall HB_PLAY_OpenFileExA(LPCSTR sFile);
HBAPI long __stdcall HB_PLAY_OpenFileExW(LPCWSTR sFile);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_CloseFile.
// Description:
//      Closes the channel, which was opened by HB_PLAY_OpenFile or HB_PLAY_OpenFileEx.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_CloseFile(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function:
//      HB_PLAY_Play.
// Description:
//      Start to play a file or stream.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] hWnd - Handle to the window for displaying video.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_Play(long nChl, HWND hWnd);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_Pause.
// Description:
//      Pauses the play of the file.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_Pause(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_Stop.
// Description:
//      Stops the play of the file.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Valid when the channel is opened by HB_PLAY_OpenFile or HB_PLAY_OpenFileEx.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_Stop(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_Fast.
// Description:
//      Speeds up the play rate.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      For each call, the play rate speeds up to the twice of the original rate.
//      Maintains the maximum rate if it has already speeded up to the 16 times
//      of the normal rate.
//      Call HB_PLAY_Play to resume the normal rate from current frame.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_Fast(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_Slow.
// Description:
//      Slows down the play rate.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      For each call, the play rate slows down to the half of the original rate.
//      Maintains the minimum rate if it has already slowed down to 1/16 of the normal rate.
//      Call HB_PLAY_Play to resume the normal rate from current frame.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_Slow(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OneByOne.
// Description:
//      Plays one single frame forward.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      For each call, plays one frame forward.
//      HB_PLAY_PlayBySingleFrame is the same as HB_PLAY_OneByOne.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_OneByOne(long nChl);
HBAPI BOOL __stdcall HB_PLAY_PlayBySingleFrame(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OneByOneBack.
// Description:
//      Plays one single frame backwards.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      For each call, plays one frame backwards.
//      Valid when the index has been created.
//      HB_PLAY_PlayBySingleFrameBack is the same as HB_PLAY_OneByOneBack.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_OneByOneBack(long nChl);
HBAPI BOOL __stdcall HB_PLAY_PlayBySingleFrameBack(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_PlayBack.
// Description:
//      Plays backwards continuously from current frame.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Valid when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_PlayBack(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetFileTime.
// Description:
//      Gets the total time for playing the opened file.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The total time for playing the opened file in seconds.
// Remarks:
//      Valid when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetFileTime(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetFileTimeMilliSec.
// Description:
//      Gets the total time for playing the opened file.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The total time for playing the opened file in milliseconds.
// Remarks:
//      Valid when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetFileTimeMilliSec(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetFileFrames.
// Description:
//      Gets the total frames of the opened file.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The total frames of the opened file.
// Remarks:
//      Valid when the index has been created.
//      HB_PLAY_GetFileTotalFrames is the same as HB_PLAY_GetFileFrames.
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetFileFrames(long nChl);
HBAPI DWORD __stdcall HB_PLAY_GetFileTotalFrames(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetPlayedFrames.
// Description:
//      Gets the frames already decoded.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The frames already decoded.
// Remarks:
//      HB_PLAY_GetPlayedFrameNum is the same as HB_PLAY_GetPlayedFrames.
////////////////////////////////////////////////////////////////////////////////
HBAPI long __stdcall HB_PLAY_GetPlayedFrames(long nChl);
HBAPI long __stdcall HB_PLAY_GetPlayedFrameNum(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetCurrFrameRate.
// Description:
//      Gets the current frame rate.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The current frame rate.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetCurrFrameRate(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetPlaySpeed.
// Description:
//      Sets play rate for speeding up or slowing down.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] dwSpeed - Effective values: 2, 4, 8 and 16.
//      [in] bSlow - If TRUE, slow down; otherwise speed up.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Call HB_PLAY_Play to play normally.
//      If bSlow is FALSE, the play rate equals the value of dwSpeed.
//      If bSlow is TRUE, the play rate equals the reciprocal of the value of dwSpeed.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetPlaySpeed(long nChl, long dwSpeed, BOOL bSlow);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetCurrentFrameNum.
// Description:
//      Gets current frame number.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Current frame number.
// Remarks:
//      HB_PLAY_GetCurrFrameNum is the same as HB_PLAY_GetCurrentFrameNum.
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetCurrentFrameNum(long nChl);
HBAPI long __stdcall HB_PLAY_GetCurrFrameNum(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetCurrentFrameNum.
// Description:
//      Sets current frame number.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] dwFrameNum - Current frame number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Valid when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetCurrentFrameNum(long nChl, DWORD dwFrameNum);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetPlayedTimeEx.
// Description:
//      Gets current playing time.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      HB_PLAY_GetPlayTime is the same as HB_PLAY_GetPlayedTimeEx.
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetPlayedTimeEx(long nChl);
HBAPI DWORD __stdcall HB_PLAY_GetPlayTime(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetPlayedTimeEx.
// Description:
//      Sets current playing time.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] dwTime - Current playing time in milliseconds.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Both HB_PLAY_GetCurrentFrameNum and HB_PLAY_SetPlayTime are the same
//      as HB_PLAY_SetPlayedTimeEx.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetPlayedTimeEx(long nChl, DWORD dwTime);
HBAPI BOOL __stdcall HB_PLAY_SetPlayedTime(long nChl, DWORD dwTime);
HBAPI BOOL __stdcall HB_PLAY_SetPlayTime(long nChl, DWORD dwTime);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetPlayPos.
// Description:
//      Gets play position.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Play position in percentage.
// Remarks:
//      Valid when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI float __stdcall HB_PLAY_GetPlayPos(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetPlayPos.
// Description:
//      Sets play position.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] dPos - Play position in percentage.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Valid when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetPlayPos(long nChl, float dPos);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetFileEndMsg.
// Description:
//      Sets the window specified by hWnd to receive the message specified by nMsg
//      when the file is played to the end.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] hWnd - The handle of the window.
//      [in] nMsg - The message ID.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetFileEndMsg(long nChl, HWND hWnd, UINT nMsg);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OpenSound.
// Description:
//      Opens sound.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      HB_PLAY_PlaySound is the same as HB_PLAY_OpenSound.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_OpenSound(long nChl);
HBAPI BOOL __stdcall HB_PLAY_PlaySound(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_CloseSound.
// Description:
//      Closes sound.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      If the sound has been opened by HB_PLAY_OpenSound or HB_PLAY_PlaySound,
//      call this function to stop playing audio. 
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_CloseSound(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetVolume.
// Description:
//      Gets the volume of the sound.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The volume of the sound.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI WORD __stdcall HB_PLAY_GetVolume(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetVolume.
// Description:
//      Sets the volume of the sound.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] nVolume - The volume of the sound, ranging from 0 to 65535.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetVolume(long nChl, WORD nVolume);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetPictureSize.
// Description:
//      Gets the original size of the picture.
// Parameters: 
//      [in] nChl - Channel number.
//      [out] pWidth - The pointer to the original picture width .
//      [out] pHeight - The pointer to the original picture height.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Couldn't get correct value until a frame is decoded successfully.
//      If the picture size changes, call this function to get the new value.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_GetPictureSize(long nChl, long* pWidth, long* pHeight);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_RegisterDrawDCFun.
// Description: 
//      Sets callback function.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] DrawDCFun - Callback function pointer.
//           void CALLBACK DrawDCFun(long nChl, HDC hDC, long nReserved);
//              - [in] nChl - Channel number.
//              - [out] hDC - The handle of DC.
//              - [out] nReserved - Reserved.
//      [in] nReserved - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      This function would be called when the index has been created.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_RegisterDrawDCFun(long nChl, LPDRAWDCFUN DrawDCFun, long nReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_ConvertToBMPFile.
// Description:
//      Converts YUV data to BMP data, and saves to file.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] pBuf - The pointer to the YUV data.
//      [in] nSize - Data size.
//      [in] nWidth - Picture width.
//      [in] nHeight - Picture height.
//      [in] nType - The formats of YUV data. For format details, refer to the
//           decoding formats for the output in Macro definition.
//      [in] sFileName - BMP file name to save.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_ConvertToBMPFile(long nChl, char* pBuf, long nSize,
             long nWidth, long nHeight, long nType, char* sFileName);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_ConvertToBMPFileEx.
// Description:
//      Converts YUV data to BMP data.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] pBuf - The pointer to the YUV data.
//      [in] nSize - Data size.
//      [in] nWidth - Picture width.
//      [in] nHeight - Picture height.
//      [in] nType - The formats of YUV data. For format details, refer to the
//           decoding formats for the output in Macro definition.
//      [out] pBufDestination - The pointer to the output data.
//      [out] len - The pointer to the length of the output data.
//      [out] pBMPHeadLen - The pointer to the length of the output BMP data header.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_ConvertToBMPFileEx(long nChl, char* pBuf,
            long nSize, long nWidth, long nHeight, long nType,
            unsigned char* pBufDestination, int* len, int* pBMPHeadLen);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetDecCallBackEx.
// Description:
//      Sets callback function after decoding.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] DecCBFun - The callback function pointer.
//           void CALLBACK DecCBFun(long nChl, char* pBuf, long nSize, 
//              FRAME_INFO* pFrameInfo, long nReserved1, long nReserved2);
//              - [in] nChl - Channel number.
//              - [out] pBuf - The pointer to the output YUV data.
//              - [out] nSize - The size of the output YUV data.
//              - [out] pFrameInfo - The pointer to the frame information.
//              - [out] pContext - Pointer to a user defined variable.
//              - [out] nReserved - Reserved.
//      [in] pContext - Pointer to a user defined variable.
//      [in] nReserved - Reserved.
//      [in] nOutFormat - The formats of output YUV data. For format details, refer
//           to the decoding formats for the output in Macro definition.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetDecCallBackEx(long nChl, LPDECCBFUN DecCBFun,
            LPVOID pContext, long nReserved,long nOutFormat);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetParseCallBack.
// Description:
//      Sets callback function.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] SrcDataParseCBFun - Callback function pointer.
//           void CALLBACK SrcDataParseCBFun(long nChl, char* SrcDataBuf, long nFrameType,
//	            long nReserved1,long nReserved2, HB_VIDEO_TIME ets);
//              - [in] nChl - Channel number.
//              - [out] SrcDataBuf - The pointer to the original data of a frame.
//              - [out] nFrameType - Frame type.
//              - [out] nReserved1 - Reserved.
//              - [out] nReserved2 - The size of the original data of a frame.
//              - [out] ets - Time stamp of the frame.
//      [in] nReserved1 - Reserved.
//      [in] nReserved2 -  Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetParseCallBack(long nChl, LPSRCDATAPARSECBFUN SrcDataParseCBFun, 
            long nReserved1,long nReserved2);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetParseCallBackEx.
// Description:
//      Sets callback function.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] pfnParse - Callback function pointer.
//           void CALLBACK SrcDataParseCBFun(long nChl, const HB_FRAME* pFrame, LPVOID pContext);
//              - [in] nChl - Channel number.
//              - [out] pFrame - The pointer to the original data of a frame.
//              - [out] pContext - Reserved.
//      [in] pContext - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetParseCallBackEx(long nChl,
            LPSRCDATAPARSECBFUNEX pfnParse, LPVOID pContext );

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetParseOnly.
// Description:
//      Sets whether to decode or not.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] bParseOnly - Decode or not.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      If bParseOnly is TRUE, the SDK does not execute decoding.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetParseOnly(long nChl,BOOL bParseOnly);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetPlayOption.
// Description:
//      Sets play options, including displaying or not, and playing audio or not.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] bEnableDisplay - Display or not.
//      [in] bEnableSound - Play audio or not.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetPlayOption(long nChl, long bEnableDisplay, long bEnableSound);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetPicQuality.
// Description:
//      Sets the quality of the decoding picture: high or low.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] bHighQuality - Picture quality: TRUE for high, and FALSE for low.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Only valid for the device that hbst.dll supports.
//      High quality by default.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetPicQuality(long nChl, BOOL bHighQuality);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetPicQuality.
// Description:
//      Gets the quality of the decoding picture.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] bHighQuality - Picture quality.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_GetPicQuality(long nChl, BOOL* bHighQuality);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetOverlayMode.
// Description:
//      Sets overlay mode.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] bOverlayMode - Overlay mode display or not.
//      [in] colorKey - The color value.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Valid for one channel only.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetOverlayMode(long nChl, BOOL bOverlayMode, COLORREF colorKey);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetDisplayRegion.
// Description:
//      Sets display region.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] nRegionNum - Display region number from 1 to (MAX_DISPLAY_WND-1).
//      [in] pSrcRect - The pointer to the original picture region.
//      [in] hDestWnd - Handle of the destination window.
//      [in] bEnable - Enable or disable the display region.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetDisplayRegion(long nChl, DWORD nRegionNum,
								RECT* pSrcRect, HWND hDestWnd, BOOL bEnable);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OpenStream.
// Description:
//      Opens stream.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] pFileHeadBuf - The pointer to the header buffer of the stream data.
//      [in] dwSize - The size of the header buffer of the stream data.
//      [in] dwReserved - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      When the channel is no longer needed, close it by HB_PLAY_CloseStream.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_OpenStream(long nChl, char* pFileHeadBuf, DWORD dwSize, DWORD dwReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_OpenStreamEx.
// Description:
//      Searches for an unoccupied channel to open stream.
// Parameters: 
//      [in] pFileHeadBuf - The pointer to the header buffer of the stream data.
//      [in] dwSize - The size of the header buffer of the stream data.
//      [in] dwReserved - Reserved.
// Return:
//      If the channel is opened successfully, this function returns a valid channel
//      number, which can also be considered as channel handle; otherwise returns 0.
// Remarks:
//      When the channel is no longer needed, close it by HB_PLAY_CloseStream.
////////////////////////////////////////////////////////////////////////////////
HBAPI long __stdcall HB_PLAY_OpenStreamEx(char* pFileHeadBuf, DWORD dwSize, DWORD dwReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetStreamOpenMode.
// Description:
//      Sets the opening mode for the stream.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] nMode - The opening mode for the stream: HB_STREAM_FILE_MODE,
//                   HB_STREAM_REALTIME_MODE by default.
//                   For mode details, refer to HB_PLAY_MODE.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Must call this function before HB_PLAY_Play.
//      Valid when the channel is opened by HB_PLAY_OpenStream or HB_PLAY_OpenStreamEx.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetStreamOpenMode(long nChl, DWORD nMode);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetStreamOpenMode.
// Description:
//      Gets the opening mode for the stream.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The opening mode for the stream. For mode details, refer to HB_PLAY_MODE.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD __stdcall HB_PLAY_GetStreamOpenMode(long nChl);


////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_InputData.
// Description:
//      Inputs stream data.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] pBuf - Stream data.
//      [in] dwnSize - Stream data size.
//      [in] dwReserved - Reserved, must be zero.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Valid when HB_PLAY_OpenStream or HB_PLAY_OpenStreamEx is called.
//      This function would return FALSE if the stream data is input too fast.
//      In this case, the stream data should be input once more.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_InputData(long nChl, char* pBuf, DWORD dwSize, DWORD dwReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_CloseStream.
// Description:
//      Closes the stream, which is opened by HB_PLAY_OpenStream or HB_PLAY_OpenStreamEx..
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_CloseStream(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetMsgWnd.
// Description:
//      Sets the window to receive the message when the index has been created.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] hWnd - Handle to the window to receive the MSG_INDEX_OK message.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetMsgWnd(long nChl, HWND hWnd);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SnapShot.
// Description:
//      Catches a picture, and saves it to an assigned file.
// Parameters:
//      [in] nChl - Channel number.
//      [in] sFile - File name.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      There are two versions of the function, ANSI and Unicode:
//      HB_PLAY_SnapshotA, ANSI version.
//      HB_PLAY_SnapshotW, Unicode version.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SnapShot(long nChl, LPCSTR sFile);
HBAPI BOOL __stdcall HB_PLAY_SnapshotA(long nChl, LPCSTR sFile);
HBAPI BOOL __stdcall HB_PLAY_SnapshotW(long nChl, LPCWSTR sFile);

#ifdef _UNICODE
#define HB_PLAY_Snapshot HB_PLAY_SnapshotW
#else
#define HB_PLAY_Snapshot HB_PLAY_SnapshotA
#endif

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetSnapShotCallBack.
// Description:
//      Sets callback function after snapshot.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] SnapshotCBFun -  Callback function pointer.
//           void CALLBACK SnapshotCBFun(long nChl, DWORD nSize, char* pBuf,
//              long nWidth, long hHeight, long nType);
//              - [in] nChl - Channel number.
//              - [out] nSize - The size of the picture.
//              - [out] pBuf - The pointer to the picture data.
//              - [out] nWidth - Picture width.
//              - [out] nHeight - Picture height.
//              - [out] nType - Data type.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Set SnapshotCBFun to NULL if one wants to stop callback.
//      Once set, it would be valid until the application quits.
//      It could be called anywhere.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetSnapShotCallBack(long nChl, LPSNAPSHOTCBFUN SnapshotCBFun);
#define HB_PLAY_SetSnapshotCallback HB_PLAY_SetSnapShotCallBack

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetDynamicBPS.
// Description:
//      Gets the real-time bit rate of the stream.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The real-time bit rate of the stream in kbps(kilobits per second).
// Remarks:
//      Returns nonzero values when played for a while.
////////////////////////////////////////////////////////////////////////////////
HBAPI double __stdcall HB_PLAY_GetDynamicBPS(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetAverageBPS.
// Description:
//      Gets the average bit rate of the stream.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The average bit rate of the stream in kbps.
// Remarks:
//      Returns nonzero values when played for a while.
////////////////////////////////////////////////////////////////////////////////
HBAPI double __stdcall HB_PLAY_GetAverageBPS(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetVideoColor.
// Description: 
//      Sets video color.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] nBrightness - Brightness, ranging from 0 to 127, 64 by default.
//      [in] nContrast - Contrast, ranging from 0 to 127, 64 by default.
//      [in] nSaturation - Saturation, ranging from 0 to 127, 64 by default4.
//      [in] nHue - Hue, ranging from 0 to 127, 64 by default.
//      [in] nReserved - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetVideoColor(long nChl, long nBrightness,
            long nContrast, long nSaturation , long nHue, long nReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetVideoColor.
// Description: 
//      Gets video color.
// Parameters: 
//      [in] nChl - Channel number.
//      [out] pBrightness - Pointer to brightness.
//      [out] pContrast - Pointer to contrast.
//      [out] pSaturation - Pointer to saturation.
//      [out] pHue - Pointer to hue.
//      [in] nReserved - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_GetVideoColor(long nChl, long* pBrightness,
            long *pContrast, long *pSaturation , long *pHue, long nReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_EnableIndexThread.
// Description: 
//      Enables or disables to create index thread.
// Parameters: 
//      [in] bEnable - Enable or disable to create index thread.
// Return:
//      None.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI void __stdcall HB_PLAY_EnableIndexThread(BOOL bEnable);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetIndexInfoCallBack.
// Description: 
//      Sets callback function.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] IndexCBFunc - Callback function pointer.
//           void CALLBACK IndexCBFunc(long nChl, long nReserved);
//              - [in] nChl - Channel number.
//              - [out] nReserved - Reserved.
//      [in] nReserved - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//	    This function would be called when the index has been creation.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetIndexInfoCallBack(long nChl, LPINDEXCBFUN IndexCBFun, long nReserved);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetIndexInfo.
// Description: 
//      Retrieves the index information.
// Parameters: 
//      [in] nChl - Channel number.
//      [out] pBuffer - Pointer to the index information.
//      [in/out] pSize - The size of the index information.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//	    Call this function for twice. Retrives the size of the index information
//	    for the first call, and the index information for the second call.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_GetIndexInfo(long nChl, HB_FRAME_POS* pBuffer, DWORD* pSize);

////////////////////////////////////////////////////////////////////////////////
// Function:
//      HB_PLAY_GetFileHead.
// Description:
//      Retrieves file header size and file header information.
// Parameters: 
//      [in] nChl - Channel number.
//      [out] pBuffer - The pointer to the file header information.
//      [in/out] pSize - The pointer to the size of the file header.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Call this function for twice. Retrives the file header size for the 
//      first call, and the file header information for the second call.
//      The second call would be valid only when the return value of the 
//      first call is nonzero.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_GetFileHead(long nChl, BYTE* pBuffer, DWORD* pSize);

////////////////////////////////////////////////////////////////////////////////
// Function:
//      HB_PLAY_SetCPULimit.
// Description:
//      Limits CPU usage. If the CPU usage is larger than the limitation,
//      decoding will be delayed.
// Parameters: 
//      [in] nCpuUse - CPU usage limitation, from 50 to 100.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      The default limitation is 100, which means that CPU usage is unlimited.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetCPULimit(int nCpuUse);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetCPULimit.
// Description: 
//      Retrieves CPU limitation.
// Parameters: 
//      [out] pCpuUse - Pointer to CPU usage limitation.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_GetCPULimit(int* pCpuUse);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_DecodeOneFrame.
// Description: 
//      Decode an audio or video frame.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] pInputFrame - Stream data, including audio or video.
//      [in] dwInputSize - Stream size, in bytes.
//      [in] nOutFormat - The formats of output YUV data. For format details, refer
//           to the decoding formats for the output in Macro definition.
// Return:
//      Nonzero if successful; otherwise 0.
//      This function would return FALSE if the stream data is input too fast.
//      In this case, the stream data should be input once more.
// Remarks:
//      
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_DecodeOneFrame(long nChl, LPCVOID pInputFrame,
            DWORD dwInputSize, long nOutFormat, PHB_FRAME_INFO_EX pFrameInfo, long* pRemainderCount);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_ResetSourceBuffer.
// Description: 
//      Clear the data in the source buffer.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_ResetSourceBuffer(long nChl);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_SetSourceBufferCB.
// Description: 
//      Sets callback function.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] dwReserved - Reserved.
//      [in] pfnSourceBufCallback - Callback function pointer.
//           void CALLBACK pfnSourceBufCallback(long nChl, DWORD dwBufSize,
//              void* pUser, void* pResvered);
//              - [in] nChl - Channel number.
//              - [out] dwBufSize - The number of frames remains in the source buffer.
//              - [out] pUser - Reserved.
//              - [out] pResvered - Reserved.
//      [in] pUser - Reserved.
//      [in] pReserved - Reserved.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//	    This function would be called when the source buffer data is less than the
//      threshold value.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetSourceBufferCB(long nChl, DWORD dwReserved,
            LPSOURCEBUFCALLBACK pfnSourceBufCallback,void* pUser,void* pReserved);

////////////////////////////////////////////////////////////////////////////////
// Function:
//      HB_PLAY_SetDecodeMode.
// Description:
//      Sets the type of hardware accelerated decoder.
// Parameters: 
//      [in] nChl - Channel number.
//      [in] nMode - The type of hardware accelerated decoder. For more details,
//           refer to enum type HB_HD_TYPE.
// Return:
//      Nonzero if successful; otherwise 0.
// Remarks:
//      Currently only HB_HD_NVIDIA_CUDA is supported.
////////////////////////////////////////////////////////////////////////////////
HBAPI BOOL __stdcall HB_PLAY_SetDecodeMode(long nChl, HB_HD_TYPE nMode);

////////////////////////////////////////////////////////////////////////////////
// Function: 
//      HB_PLAY_GetDecodeMode.
// Description: 
//      Retrieves the type of hardware accelerated decoder.
// Parameters: 
//      [in] nChl - Channel number.
// Return:
//      The type of hardware accelerated decoder.
// Remarks:
//      For more details of the return value, refer to enum type HB_HD_TYPE.
////////////////////////////////////////////////////////////////////////////////
HBAPI DWORD  __stdcall   HB_PLAY_GetDecodeMode(long nChl);


////////////////////////////////////////////////////////////////////////////////
// Undocumented functions.
////////////////////////////////////////////////////////////////////////////////

HBAPI BOOL __stdcall HB_PLAY_InitDDraw(HWND hWnd);
HBAPI BOOL __stdcall HB_PLAY_RealeseDDraw();

HBAPI BOOL __stdcall HB_PLAY_RefreshPlay(long nChl);
HBAPI BOOL __stdcall HB_PLAY_GetOverlayMode(long nChl);
HBAPI DWORD __stdcall HB_PLAY_GetColorKey(long nChl);

HBAPI DWORD __stdcall HB_PLAY_GetLastError(long nChl);
HBAPI DWORD __stdcall HB_PLAY_GetSdkVersion(long nChl);

HBAPI BOOL __stdcall HB_PLAY_SetDecCallBack(long nChl, LPDECCBFUN DecCBFun,long nOutFormat);
HBAPI BOOL __stdcall HB_PLAY_SetDecCallBackWithTime(long nChl, 
            LPDECCBFUNWITHTIME DecCBFunWithTime, long nOutFormat);
HBAPI BOOL __stdcall HB_PLAY_SetDisplayCallBack(long nChl, LPDISPLAYCBFUN DisplayCBFun);

HBAPI BOOL __stdcall HB_PLAY_GetFileStartTime(long nChl, char *pSystemTime);
HBAPI DWORD __stdcall HB_PLAY_GetFileHeadLength(long nChl);

HBAPI BOOL __stdcall HB_PLAY_SetStreamSpeed(long nChl, int iSpeed, BOOL bFast);
HBAPI void __stdcall HB_PLAY_SetEndlessStream(long	nChl, BOOL	bEndless);
HBAPI DWORD __stdcall HB_PLAY_GetSourceBufferRemain(long nChl);
HBAPI BOOL __stdcall HB_PLAY_ResetSourceBufFlag(long nChl);

HBAPI BOOL __stdcall HB_PLAY_InputVideoData(long nChl,char* pBuf,DWORD nSize);
HBAPI BOOL __stdcall HB_PLAY_InputAudioData(long nChl,char* pBuf,DWORD nSize);

HBAPI BOOL __stdcall HB_PLAY_GetKeyFramePos(long nChl, DWORD nValue,
            DWORD nType, HB_FRAME_POS* pFramePos);
HBAPI BOOL __stdcall HB_PLAY_GetPriorKeyFramePos(long nChl, DWORD nValue,
            DWORD nType, HB_FRAME_POS* pFramePos);
HBAPI BOOL __stdcall HB_PLAY_GetNextKeyFramePos(long nChl, DWORD nValue,
            DWORD nType, HB_FRAME_POS* pFramePos);

HBAPI BOOL __stdcall HB_PLAY_GetDecodedFrame(long nChl, HB_FRAME_INFO_EX* pFraminfo);


////////////////////////////////////////////////////////////////////////////////
// Special interfaces.
////////////////////////////////////////////////////////////////////////////////

// for zhuan
typedef void* HDRAW;	 
typedef void* H_WAVE;

// 1500 
HBAPI void* __stdcall HB_PLAY_DecInit(int width,int height);
HBAPI void* __stdcall HB_PLAY_DecInitEx(int width,int height,int out_fmt);
HBAPI int __stdcall HB_PLAY_DecFrame(void* handle,void* stream,int size, void* image, int quality);
HBAPI int __stdcall HB_PLAY_DecFrameEx(void* handle,void* stream,int size, void* image, int quality);
HBAPI void __stdcall HB_PLAY_DecFree(void *handle);

// 1800
HBAPI void* __stdcall HB_PLAY_DecInit18(int width,int height);
HBAPI int __stdcall HB_PLAY_DecFrame18(void* handle,void* stream,int size, void* image, int quality);
HBAPI void __stdcall HB_PLAY_DecFree18(void *handle);
HBAPI void* __stdcall HB_PLAY_DecInit18Ex(int width,int height, int colorspace);
HBAPI int __stdcall HB_PLAY_DecFrame18Ex(void* handle,void* stream, int size, void* image, int quality);

// display
HBAPI HDRAW __stdcall HB_PLAY_InitDirectDraw(long width, long height);
HBAPI BOOL __stdcall HB_PLAY_ShowPicture(void* hdraw, long hwnd,
            unsigned char* image, long width, long height);
HBAPI BOOL __stdcall HB_PLAY_ShowPictureEx(void* hdraw, unsigned char* image,
            long width, long height);
HBAPI BOOL __stdcall HB_PLAY_AddWindow(void* hdraw, long hwnd, long x, long y,
            long cx, long cy);
HBAPI BOOL __stdcall HB_PLAY_DelWindow(void* hdraw, long hwnd);
HBAPI void __stdcall HB_PLAY_RestoreSurface(void* hdraw);
HBAPI void __stdcall HB_PLAY_ReleaseDDraw(void* hdraw);

// audio, 0 <= volume <= 0xffff
HBAPI H_WAVE __stdcall HB_PLAY_WaveOpen();
HBAPI void __stdcall HB_PLAY_WaveSetVolume(H_WAVE *h, long volume);
HBAPI void __stdcall HB_PLAY_WaveGetVolume(H_WAVE *h, long &volume);
HBAPI BOOL __stdcall HB_PLAY_WaveWrite(H_WAVE *h, char *buff, long size);
HBAPI BOOL __stdcall HB_PLAY_WaveReset(H_WAVE *h);
HBAPI BOOL __stdcall HB_PLAY_WaveClose(H_WAVE *h);


// 2006-8-23 for JiuDing
HBAPI BOOL __stdcall HB_PLAY_GetKeyFramePosJD(long nChl, long lTime,
            long *iFilePos, long *iFrameSize);
HBAPI BOOL __stdcall HB_PLAY_GetNextFramePosJD(long nChl, long *iFilePos,
            long *iFrameSize, long *iType);
// Retrieves the type of stream.
HBAPI UINT __stdcall HB_PLAY_GetProductID(long nChl);

//for army
HBAPI BOOL __stdcall HB_PLAY_SetNextOsdPos(long nChl);

// for FeiLong
HBAPI BOOL __stdcall HB_PLAY_DecodeAudioFrame(long nChl, char* pBuff, DWORD dwSize);

HBAPI BOOL __stdcall HB_PLAY_PlayEx(long nChl, HWND hWnd);
HBAPI long __stdcall HB_PLAY_CheckFrameInfo(char* stream, long streamsize,
            long* pFrameType, long* pFrameSize);
HBAPI void __stdcall HB_PLAY_SetWindowClip(long nChl, BOOL bEnable, int left,
            int right, int top, int bottom);
HBAPI UINT __stdcall HB_PLAY_GetStreamType(long nChl);
HBAPI BOOL __stdcall HB_PLAY_SetDCCallBack( long nChl, long (__stdcall* CallBack)
            (long lType, long lPara1, long lPara2) );
HBAPI BOOL __stdcall HB_PLAY_SnapPicture(long nChl, char* pBuff, long* plSize,
            long* plWidth, long *plHeight, long *plType);

HBAPI BOOL __stdcall HB_PLAY_GetFrameInfo(char* stream, long streamsize, long* width, long* height);
HBAPI BOOL __stdcall HB_PLAY_UnionFiles(char* pNewFile,char* pFileDestination, char* pFileSource);
HBAPI int __stdcall HB_PLAY_SplitFiles(char* pFileSource, char* pFileDestination, 
            unsigned int StartTime, unsigned int Length);
HBAPI float __stdcall HB_PLAY_GetSchedule();
HBAPI DWORD __stdcall HB_PLAY_StopUnionFiles();

// for RongChuang
typedef struct _HB_HEAD_SKIPPED
{
    DWORD dwHeadLength;
    char sHead[64];
    DWORD dwReserved[4];
}HB_HEAD_SKIPPED, *PHB_HEAD_SKIPPED;

HBAPI BOOL __stdcall HB_PLAY_OpenFileSkip(long nChl, LPCSTR sFile, PHB_HEAD_SKIPPED pHeadSkipped);
HBAPI BOOL __stdcall HB_PLAY_OpenFileSkipEx(LPCSTR sFile, PHB_HEAD_SKIPPED pHeadSkipped);
HBAPI BOOL __stdcall HB_PLAY_OpenStreamSkip(long nChl, char* pFileHeadBuf, 
            DWORD dwSize, DWORD dwReserved, PHB_HEAD_SKIPPED pHeadSkipped);
HBAPI BOOL __stdcall HB_PLAY_OpenStreamSkipEx(char* pFileHeadBuf, DWORD dwSize, 
            DWORD dwReserved, PHB_HEAD_SKIPPED pHeadSkipped);

HBAPI DWORD	__stdcall	HB_PLAY_GetCurrentFrameTime(long nChl);

#endif